package com.example.demokafka.controller;

import com.alibaba.fastjson.JSONObject;
import com.example.demokafka.common.api.vo.Result;
import com.example.demokafka.model.Person;
import com.example.demokafka.service.ProducerService;
import com.example.demokafka.util.Kafka;
import com.example.demokafka.util.KafkaUtil;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.Consumer;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import java.util.*;

/**
 * @author 赵恒
 * @date 2023/5/11
 */
@RestController
@RequestMapping("/test")
@Slf4j
@Api(tags = "测试")
public class TestController {

    @Autowired
    private ProducerService producerService;
    @Autowired
    private KafkaTemplate<String, String> kafkaTemplate;
    @Value("${spring.kafka.topic}")
    private String topicName;

    @GetMapping("/kafka01")
    @ApiOperation(value = "kafka01")
    public List<Person> kafka01() {
        producerService.sendMessage(topicName, "测试");
        return new ArrayList<>();
    }

    @GetMapping("/consumer/{topic}")
    @ApiOperation(value = "consumer")
    public Result getConsumerData(@PathVariable String topic) {
        List<String> result = new ArrayList<>();
        Consumer<String, String> consumer = new KafkaConsumer<String, String>(KafkaUtil.getSafeConsumerPro());
        consumer.subscribe(Arrays.asList(topic));
        ConsumerRecords<String, String> records = consumer.poll(5000);
        for (ConsumerRecord<String, String> consumerRecord : records) {
            String kfkContent = consumerRecord.value();
            result.add(kfkContent);
        }
        consumer.close();
        return Result.ok(result);
    }
}
